#
# spec file for package tilde
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tilde
Version:        1.1.3
Release:        2.2
Summary:        A text editor for the terminal
License:        GPL-3.0-only
Group:          Productivity/Text/Editors
URL:            https://os.ghalkes.nl/t3/libt3widget.html

#Git-Clone:	https://github.com/gphalkes/tilde
Source:         https://os.ghalkes.nl/dist/%name-%version.tar.bz2
Source2:        https://os.ghalkes.nl/dist/%name-%version.tar.bz2.sig
Source3:        %name.keyring
BuildRequires:  c++_compiler
BuildRequires:  gettext-devel
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel
BuildRequires:  libunistring-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libt3config) >= 1.0.0
BuildRequires:  pkgconfig(libt3highlight) >= 0.4.0
BuildRequires:  pkgconfig(libt3widget) >= 1.2.0
BuildRequires:  pkgconfig(libtranscript) >= 0.2.0

%description
Tilde is a text editor for the console/terminal, which provides an
interface for people accustomed to GUI environments such as
GNOME, KDE and Windows. For example, the short-cut to copy the
current selection is Control-C, and to paste the previously copied
text the short-cut Control-V can be used. As another example, the
File menu can be accessed by pressing Alt-F.

%prep
%autosetup -p1

%build
export PKG_CONFIG=%{_bindir}/pkg-config
%configure CC=gcc CXX=g++ LIBTOOL=libtool --docdir="%_docdir/%name"
make %{?_smp_mflags}

%install
%make_install

%files
%_bindir/tilde
%_docdir/%name/
%_datadir/%name/
%_mandir/man1/tilde.1*
%license COPYING

%changelog
* Fri Feb  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: The build system used by tilde is not
  exactly autoconf, even though it's initiated by configure. IT
  mis-interprets the parameters of the configure macro to imply a
  cross build, then fails to fine the correct pkg-config
  executable. Aid the build script by defining PKG_CONFIG to
  /usr/bin/pkg-config.
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.3
  * The file name in the info line would not be displayed as
    intended if it contained double-width characters.
* Fri Jun  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.2
  * This release fixes a bug where Tilde would discard read lines
    before an invalid character, while requested to continue
    reading.
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.1
  * The base config from /usr/share/tilde/base.config now accepts
    all options.
  * Tilde maintains the list of recent files accross sessions.
  * Tilde will open a recently open file at the position is was
    at previously.
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.0.1
  * This release rewrites the file writing code such that ownership
    and permissions are never accidentally changed.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.0.0
  * Files can be opened at a specific position, by appending line
    (and column) number(s). This allows jumping to positions
    indicated by programs processing text files such as
    compilers.
  * Allow changing the default interface attributes from the
    Interface Options dialog.
  * Allow writing files if the directory they are in is not
    writable for the current user. This is ever so slightly more
    risky than creating a temporary file and moving it over the
    existing one, which is the default behavior.
  * Add menu items for the new Paste Selection (which pastes the
    X11 primary selection) and for the new Delete Line actions.
  * Make it possible to disable claiming the primary selection,
    and to automatically disable this when running over SSH. When
    running over SSH on high-latency connections and while
    running a clipboard manager locally, the primary selection
    claiming can make Tilde work slowly.
  * Rewrite files in place if the owner of the file would be
    changed by creating the file anew. This is a short-term
    solution for fixing accidental ownership changes due to the
    scheme used by Tilde to prevent file corruptions.
  * Guard against off-of-line cursor positions in finding next
    brace. This could cause infinite loops in some cases.
  * A new dialog is available that shows the codepoints under the
    cursor.
  * Allow Private-Use Area characters in input and output without
    substituion.
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 0.3.7
  * Resolve crashes that happened on program exit
  * Add a "toggle comment" functionality.
  * Several problems with syntax highlighting were fixed.
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.3.4
  * Re-release of version 0.3.4 to update the configure script.
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 0.3.3
  * This release correctly handle errors in conversion when loading
  files. When the converter failed in unexpected ways, Tilde would
  previously crash.
  * Added warnings about trying to overwrite a read-only file,
  improved the warnings about encoding issues when saving and fixed
  the setting of the comment-keyword style.
* Mon Jun 10 2013 jengelh@inai.de
- Initial package (version 0.3.0) for build.opensuse.org
